==> al_downloader-1.7.0.tar.gz: lib/src/internal/ALDownloaderConstant.dart <==
abstract class ALDownloaderConstant {
  static final kInitiallize = 'initialize';
  static final kDownload = 'download';
  static final kDownloaderHandlerInterfaceId = 'downloaderHandlerInterfaceId';
  static final kHeaders = 'headers';
  static final kUrl = 'url';
  static final kUrls = 'urls';
  static final kAddDownloaderHandlerInterface = 'addDownloaderHandlerInterface';
  static final kAddForeverDownloaderHandlerInterface =
      'addForeverDownloaderHandlerInterface';
  static final kRemoveDownloaderHandlerInterfaceForUrl =
      'removeDownloaderHandlerInterfaceForUrl';
  static final kRemoveDownloaderHandlerInterfaceForAll =
      'removeDownloaderHandlerInterfaceForAll';
  static final kPause = 'pause';
  static final kPauseAll = 'pauseAll';
  static final kCancel = 'cancel';
  static final kCancelAll = 'cancelAll';
  static final kRemove = 'remove';
  static final kRemoveAll = 'removeAll';
  static final kRootIsolateToken = 'rootIsolateToken';
  static final kStoragePortRootToAL = 'storagePortRootToAL';
  static final kPortALToRoot = 'portALToRoot';
  static final kPrintEnabled = 'printEnabled';
  static final kFrequentPrintEnabled = 'frequentPrintEnabled';
  static final kSyncTaskToRoot = 'syncTaskToRoot';
  static final kTask = 'kTask';
  static final kCallInterface = 'callInterface';
  static final kIsNeedCallProgressHandler = 'isNeedCallProgressHandler';
  static final kIsNeedCallSucceededHandler = 'isNeedCallSucceededHandler';
  static final kIsNeedCallFailedHandler = 'isNeedCallFailedHandler';
  static final kIsNeedCallPausedHandler = 'isNeedCallPausedHandler';
  static final kProgress = 'progress';
  static final kIsNeedRemoveInterfaceAfterCallForRoot =
      'isNeedRemoveInterfaceAfterCallForRoot';
  static final kConfigurePrint = 'configurePrint';
  static final kEnabled = 'enabled';
  static final kFrequentEnabled = 'frequentEnabled';
  static final kALDownloaderIMP = 'ALDownloaderIMP';
  static final kALDownloaderBatcherIMP = 'ALDownloaderBatcherIMP';
  static final kDownloadUrlsWithVOs = 'downloadUrlsWithVOs';
  static final kALDownloaderBatcherInputVOs = 'ALDownloaderBatcherInputVOs';
  static final kRemoveDownloaderHandlerInterfaceForUrls =
      'removeDownloaderHandlerInterfaceForUrls';
  static final kGlobalScope = 'globalScope';
}

==> al_downloader-1.7.1.tar.gz: lib/src/internal/ALDownloaderConstant.dart <==
abstract class ALDownloaderConstant {
  static final kInitiallize = 'initialize';
  static final kDownload = 'download';
  static final kDownloaderHandlerInterfaceId = 'downloaderHandlerInterfaceId';
  static final kHeaders = 'headers';
  static final kUrl = 'url';
  static final kUrls = 'urls';
  static final kAddDownloaderHandlerInterface = 'addDownloaderHandlerInterface';
  static final kAddForeverDownloaderHandlerInterface =
      'addForeverDownloaderHandlerInterface';
  static final kRemoveDownloaderHandlerInterfaceForUrl =
      'removeDownloaderHandlerInterfaceForUrl';
  static final kRemoveDownloaderHandlerInterfaceForAll =
      'removeDownloaderHandlerInterfaceForAll';
  static final kPause = 'pause';
  static final kPauseAll = 'pauseAll';
  static final kCancel = 'cancel';
  static final kCancelAll = 'cancelAll';
  static final kRemove = 'remove';
  static final kRemoveAll = 'removeAll';
  static final kRootIsolateToken = 'rootIsolateToken';
  static final kStoragePortRootToAL = 'storagePortRootToAL';
  static final kPortALToRoot = 'portALToRoot';
  static final kPrintEnabled = 'printEnabled';
  static final kFrequentPrintEnabled = 'frequentPrintEnabled';
  static final kTask = 'kTask';
  static final kCallInterface = 'callInterface';
  static final kIsNeedCallProgressHandler = 'isNeedCallProgressHandler';
  static final kIsNeedCallSucceededHandler = 'isNeedCallSucceededHandler';
  static final kIsNeedCallFailedHandler = 'isNeedCallFailedHandler';
  static final kIsNeedCallPausedHandler = 'isNeedCallPausedHandler';
  static final kStatus = 'status';
  static final kProgress = 'progress';
  static final kIsNeedRemoveInterface = 'isNeedRemoveInterface';
  static final kConfigurePrint = 'configurePrint';
  static final kEnabled = 'enabled';
  static final kFrequentEnabled = 'frequentEnabled';
  static final kALDownloaderIMP = 'ALDownloaderIMP';
  static final kALDownloaderBatcherIMP = 'ALDownloaderBatcherIMP';
  static final kDownloadUrlsWithVOs = 'downloadUrlsWithVOs';
  static final kALDownloaderBatcherInputVOs = 'ALDownloaderBatcherInputVOs';
  static final kRemoveDownloaderHandlerInterfaceForId =
      'removeDownloaderHandlerInterfaceForId';
  static final kGlobalScope = 'globalScope';
  static final kGetStatusForUrl = 'getStatusForUrl';
  static final kGetStatusForUrls = 'getStatusForUrls';
  static final kStatusHandlerId = 'statusHandlerId';
  static final kCallStatusHandler = 'callStatusHandler';
  static final kGetProgressForUrl = 'getProgressForUrl';
  static final kGetProgressForUrls = 'getProgressForUrls';
  static final kProgressHandlerId = 'progressHandlerId';
  static final kCallProgressHandler = 'callProgressHandler';
}
